<?php
/**
*
* @package acp
* @version $Id: acp_newsletter.php,v 1.002 2010/09/15 Martin Truckenbrodt Exp $
* @copyright (c) 2009 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

/**
* @package acp
*/
class acp_newsletter
{
	var $u_action;

	function main($id, $mode)
	{
		global $config, $db, $user, $auth, $template, $cache;
		global $phpbb_root_path, $phpbb_admin_path, $phpEx, $table_prefix;

		include($phpbb_root_path . 'includes/newsletter/constants.' . $phpEx);
		include($phpbb_root_path . 'includes/newsletter/functions_admin.' . $phpEx);

		$user->add_lang('mods/newsletter');

		$this->tpl_name = 'acp_newsletter_manage';
		$this->page_title = 'ACP_NEWSLETTER_MANAGE';

		$form_key = 'acp_newsletter';
		add_form_key($form_key);

		// Check the permission setting again
		if (!$auth->acl_get('a_newsletter'))
		{
			trigger_error($user->lang['NO_AUTH_OPERATION'] . adm_back_link($this->u_action), E_USER_WARNING);
		}

		$action			= request_var('action', '');
		$update			= (isset($_POST['update'])) ? true : false;
		$newsletter_id	= request_var('n', 0);

		$newsletter_data = $errors = array();
		if ($update && !check_form_key($form_key))
		{
			$update = false;
			$errors[] = $user->lang['FORM_INVALID'];
		}

		// Major routines
		if ($update)
		{
			switch ($action)
			{
				case 'delete':

					$errors = delete_newsletter($newsletter_id);

					if (sizeof($errors))
					{
						break;
					}

					$auth->acl_clear_prefetch();
					$cache->destroy('sql', NEWSLETTER_TABLE);

					trigger_error($user->lang['NEWSLETTER_DELETED'] . adm_back_link($this->u_action));

				break;

				case 'edit':
					$newsletter_data = array(
						'newsletter_id'		=>	$newsletter_id
					);

				//no break;

				case 'add':

					$newsletter_data += array(
						'newsletter_name'				=> utf8_normalize_nfc(request_var('newsletter_name', '', true)),
						'newsletter_desc'				=> utf8_normalize_nfc(request_var('newsletter_desc', '', true)),
						'newsletter_type'				=> request_var('newsletter_type', 0),
						'newsletter_lang'				=> request_var('newsletter_lang', ''),
						'newsletter_footer'				=> utf8_normalize_nfc(request_var('newsletter_footer', '', true)),
						'newsletter_desc_bitfield'		=> '',
						'newsletter_desc_options'		=> 7,
						'newsletter_desc_uid'			=> '',
						'newsletter_footer_bitfield'	=> '',
						'newsletter_footer_options'		=> 7,
						'newsletter_footer_uid'			=> '',
						'newsletter_css'				=> utf8_normalize_nfc(request_var('newsletter_css', '', true)),
						'newsletter_public'				=> request_var('newsletter_public', 0),
					);

					$bbcode_status	= ($config['allow_bbcode'] && $config['allow_newsletter_bbcode']) ? true : false;
					$img_status		= ($config['allow_newsletter_img']) ? true : false;
					$url_status		= ($config['allow_newsletter_links']) ? true : false;

					// Get data for newsletter description if specified
					if ($newsletter_data['newsletter_desc'])
					{
						generate_text_for_storage($newsletter_data['newsletter_desc'], $newsletter_data['newsletter_desc_uid'], $newsletter_data['newsletter_desc_bitfield'], $newsletter_data['newsletter_desc_options'], $bbcode_status, $url_status, '');
					}

					// Get data for newsletter footer if specified
					if ($newsletter_data['newsletter_footer'])
					{
						generate_text_for_storage($newsletter_data['newsletter_footer'], $newsletter_data['newsletter_footer_uid'], $newsletter_data['newsletter_footer_bitfield'], $newsletter_data['newsletter_footer_options'], $bbcode_status, $url_status, '');
					}

					$errors = update_newsletter_data($newsletter_data);

					trigger_error($user->lang['NEWSLETTER_ADDED_EDITED'] . adm_back_link($this->u_action));

				break;
			}
		}

		switch ($action)
		{
			case 'move_up':
			case 'move_down':

				if (!$newsletter_id)
				{
					trigger_error($user->lang['NO_NEWSLETTER'] . adm_back_link($this->u_action), E_USER_WARNING);
				}

				$sql = 'SELECT newsletter_id, newsletter_name, left_id, right_id FROM ' . NEWSLETTER_TABLE . '
					WHERE newsletter_id = ' . $newsletter_id;
				$result = $db->sql_query($sql);
				$row = $db->sql_fetchrow($result);
				$db->sql_freeresult($result);

				if (!$row)
				{
					trigger_error($user->lang['NO_NEWSLETTER'] . adm_back_link($this->u_action), E_USER_WARNING);
				}

				$move_newsletter_name = move_newsletter_by($row, $action);

				if ($move_newsletter_name !== false)
				{
					add_log('admin', 'LOG_NEWSLETTER_' . strtoupper($action), $row['newsletter_name'], $move_newsletter_name);
					$cache->destroy('sql', NEWSLETTER_TABLE);
				}

			break;

			case 'add':
			case 'edit':

				// Show form to create/modify a newsletter
				if ($action == 'edit')
				{
					$this->page_title = 'NEWSLETTER_EDIT';

					$row = get_newsletter_info($newsletter_id);
					$old_newsletter_type = $row['newsletter_type'];

					if (!$update)
					{
						$newsletter_data = $row;
					}
					else
					{
						$newsletter_data['left_id'] = $row['left_id'];
						$newsletter_data['right_id'] = $row['right_id'];
					}
				}
				else
				{
					$this->page_title = 'NEWSLETTER_CREATE';

					// Fill newsletter data with default values
					if (!$update)
					{
						$newsletter_data = array(
							'newsletter_type'		=> NEWSLETTER_OPTIONAL,
							'newsletter_name'		=> utf8_normalize_nfc(request_var('newsletter_name', '', true)),
							'newsletter_desc'		=> '',
							'newsletter_lang'		=> '',
							'newsletter_footer'		=> '',
							'newsletter_css'		=> '',
							'newsletter_public'		=> NEWSLETTER_CLOSED,
						);
					}
				}

				$newsletter_desc_data = array(
					'text'			=> $newsletter_data['newsletter_desc'],
					'allow_bbcode'	=> true,
					'allow_urls'	=> true
				);

				$newsletter_footer_data = array(
					'text'			=> $newsletter_data['newsletter_footer'],
					'allow_bbcode'	=> true,
					'allow_urls'	=> true
				);

				// Parse desrciption if specified
				if ($newsletter_data['newsletter_desc'])
				{
					if (!isset($newsletter_data['newsletter_desc_uid']))
					{
						// Before we are able to display the preview and plane text, we need to parse our request_var()'d value...
						$newsletter_data['newsletter_desc_uid'] = '';
						$newsletter_data['newsletter_desc_bitfield'] = '';
						$newsletter_data['newsletter_desc_options'] = 0;

						generate_text_for_storage($newsletter_data['newsletter_desc'], $newsletter_data['newsletter_desc_uid'], $newsletter_data['newsletter_desc_bitfield'], $newsletter_data['newsletter_desc_options'], request_var('desc_allow_bbcode', false), request_var('desc_allow_urls', false), '');
					}

					// decode...
					$newsletter_desc_data = generate_text_for_edit($newsletter_data['newsletter_desc'], $newsletter_data['newsletter_desc_uid'], $newsletter_data['newsletter_desc_options']);
				}

				$newsletter_type_options = '';
				$newsletter_type_ary = array(NEWSLETTER_OPTIONAL => 'OPTIONAL', NEWSLETTER_GROUP => 'GROUP', NEWSLETTER_BOARD => 'BOARD');

				foreach ($newsletter_type_ary as $value => $lang)
				{
					$newsletter_type_options .= '<option value="' . $value . '"' . (($value == $newsletter_data['newsletter_type']) ? ' selected="selected"' : '') . '>' . $user->lang['NEWSLETTER_' . $lang] . '</option>';
				}

				// Parse footer if specified
				if ($newsletter_data['newsletter_footer'])
				{
					if (!isset($newsletter_data['newsletter_footer_uid']))
					{
						// Before we are able to display the preview and plane text, we need to parse our request_var()'d value...
						$newsletter_data['newsletter_footer_uid'] = '';
						$newsletter_data['newsletter_footer_bitfield'] = '';
						$newsletter_data['newsletter_footer_options'] = 0;

						generate_text_for_storage($newsletter_data['newsletter_footer'], $newsletter_data['newsletter_footer_uid'], $newsletter_data['newsletter_footer_bitfield'], $newsletter_data['newsletter_footer_options'], request_var('footer_allow_bbcode', false), request_var('footer_allow_urls', false), '');
					}

					// decode...
					$newsletter_footer_data = generate_text_for_edit($newsletter_data['newsletter_footer'], $newsletter_data['newsletter_footer_uid'], $newsletter_data['newsletter_footer_options']);
				}

				$template->assign_vars(array(
					'S_NEWSLETTER_EDIT'				=> true,
					'S_ERROR'						=> (sizeof($errors)) ? true : false,
					'S_ADD_ACTION'					=> ($action == 'add') ? true : false,
					'U_BACK'						=> $this->u_action,
					'U_EDIT_ACTION'					=> $this->u_action . "&amp;action=$action&amp;n=$newsletter_id",
					'L_TITLE'						=> $user->lang[$this->page_title],
					'ERROR_MSG'						=> (sizeof($errors)) ? implode('<br />', $errors) : '',
					'S_NEWSLETTER_TYPE_OPTIONS'		=> $newsletter_type_options,
					'NEWSLETTER_NAME'				=> $newsletter_data['newsletter_name'],
					'NEWSLETTER_DESC'				=> $newsletter_desc_data['text'],
					'S_NEWSLETTER_LANG_OPTIONS'		=> newsletter_language_select($newsletter_data['newsletter_lang']),
					'NEWSLETTER_FOOTER'				=> $newsletter_footer_data['text'],
					'NEWSLETTER_CSS'				=> $newsletter_data['newsletter_css'],
					'S_NEWSLETTER_ORIG_OPTIONAL'	=> (isset($old_newsletter_type) && $old_newsletter_type == NEWSLETTER_OPTIONAL) ? true : false,
					'S_NEWSLETTER_ORIG_GROUP'		=> (isset($old_newsletter_type) && $old_newsletter_type == NEWSLETTER_GROUP) ? true : false,
					'S_NEWSLETTER_ORIG_BOARD'		=> (isset($old_newsletter_type) && $old_newsletter_type == NEWSLETTER_BOARD) ? true : false,
					'S_NEWSLETTER_OPTIONAL'			=> ($newsletter_data['newsletter_type'] == NEWSLETTER_OPTIONAL) ? true : false,
					'S_NEWSLETTER_BOARD'			=> ($newsletter_data['newsletter_type'] == NEWSLETTER_BOARD) ? true : false,
					'S_NEWSLETTER_GROUP'			=> ($newsletter_data['newsletter_type'] == NEWSLETTER_GROUP) ? true : false,
					'NEWSLETTER_PUBLIC'				=> $newsletter_data['newsletter_public'],
					'S_PUBLIC_CLOSED'				=> ($newsletter_data['newsletter_public'] == NEWSLETTER_CLOSED) ? true : false,
					'S_PUBLIC_REGISTERED'			=> ($newsletter_data['newsletter_public'] == NEWSLETTER_REGISTERED) ? true : false,
					'S_PUBLIC_ANONYMOUS'			=> ($newsletter_data['newsletter_public'] == NEWSLETTER_ANONYMOUS) ? true : false,

				));

				$cache->destroy('sql', NEWSLETTER_TABLE);

				return;

			break;

			case 'delete':

				if (!$newsletter_id)
				{
					trigger_error($user->lang['NO_NEWSLETTER'] . adm_back_link($this->u_action), E_USER_WARNING);
				}

				$sql = 'SELECT newsletter_name FROM ' . NEWSLETTER_TABLE . '
					WHERE newsletter_id= ' . $newsletter_id;
				$result = $db->sql_query($sql);
				$newsletter_data = $db->sql_fetchrow($result);
				$db->sql_freeresult($result);

				$template->assign_vars(array(
					'S_NEWSLETTER_DELETE'	=> true,
					'U_ACTION'				=> $this->u_action . "&amp;action=delete&amp;n=$newsletter_id",
					'U_BACK'				=> $this->u_action,
					'NEWSLETTER_NAME'		=> $newsletter_data['newsletter_name'],
					'S_ERROR'				=> (sizeof($errors)) ? true : false,
					'ERROR_MSG'				=> (sizeof($errors)) ? implode('<br />', $errors) : '')
				);

				$cache->destroy('sql', NEWSLETTER_TABLE);

				return;

			break;
		}

		$sql = 'SELECT newsletter_id, newsletter_name, newsletter_type, newsletter_desc, newsletter_desc_bitfield, newsletter_desc_uid, newsletter_desc_options FROM ' . NEWSLETTER_TABLE . '
			ORDER BY left_id ASC';
		$result = $db->sql_query($sql);

		if ($row = $db->sql_fetchrow($result))
		{
			do
			{
				$newsletter_type = $row['newsletter_type'];

				$url = $this->u_action . "&amp;n={$row['newsletter_id']}";

				$template->assign_block_vars('newsletter', array(
					'NEWSLETTER_NAME'	=> $row['newsletter_name'],
					'NEWSLETTER_DESC'	=> generate_text_for_display($row['newsletter_desc'], $row['newsletter_desc_uid'], $row['newsletter_desc_bitfield'], $row['newsletter_desc_options']),

					'S_NEWSLETTER_BOARD'		=> ($newsletter_type == NEWSLETTER_BOARD) ? true : false,
					'S_NEWSLETTER_OPTIONAL'		=> ($newsletter_type == NEWSLETTER_OPTIONAL) ? true : false,

					'U_MOVE_UP'			=> $url . '&amp;action=move_up',
					'U_MOVE_DOWN'		=> $url . '&amp;action=move_down',
					'U_EDIT'			=> $url . '&amp;action=edit',
					'U_DELETE'			=> $url . '&amp;action=delete',
				));
			}
			while ($row = $db->sql_fetchrow($result));
		}

		$db->sql_freeresult($result);

		$template->assign_vars(array(
			'ERROR_MSG'		=> (sizeof($errors)) ? implode('<br />', $errors) : '',
			'U_ACTION'		=> $this->u_action,

		));

	}

}

?>