<?php
/**
*
* @package acp
* @version $Id: acp_newsletter_perm.php,v 1.003 2010/08/06 Martin Truckenbrodt Exp $
* @copyright (c) 2009 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

/**
* @package acp
*/
class acp_newsletter_perm
{
	var $u_action;

	function main($id, $mode)
	{
		global $db, $user, $auth, $template, $cache;
		global $config, $phpbb_admin_path, $phpbb_root_path, $phpEx;

		include($phpbb_root_path . 'includes/newsletter/constants.' . $phpEx);
		include($phpbb_root_path . 'includes/newsletter/functions_admin.' . $phpEx);
		include($phpbb_root_path . 'includes/functions_user.' . $phpEx);

		$user->add_lang('mods/newsletter');

		$this->tpl_name = 'acp_newsletter_perm';
		$this->page_title = 'ACP_NEWSLETTER_PERM';

		$user->add_lang('acp/permissions');

		// Check the permission setting again
		if (!$auth->acl_get('a_newsletter'))
		{
			trigger_error($user->lang['NO_AUTH_OPERATION'] . adm_back_link($this->u_action), E_USER_WARNING);
		}

		$action			= request_var('action', array('' => 0));
		$action			= key($action);
		$update			= (isset($_POST['update'])) ? true : false;
		$newsletter_id	= request_var('newsletter_id', 0);

		$username			= utf8_normalize_nfc(request_var('username', array(''), true));
		$usernames			= utf8_normalize_nfc(request_var('usernames', '', true));
		$user_id			= request_var('user_id', array(0));
		$select_all_users	= request_var('select_all_users', 0);

		$group_id			= request_var('group_id', array(0));
		$select_all_groups	= request_var('select_all_groups', 0);

		// If select all groups is set, we pre-build the group id array (this option is used for other screens to link to the permission settings screen)
		if ($select_all_groups)
		{
			// Add default groups to selection
			$sql_and = (!$config['coppa_enable']) ? " AND group_name <> 'REGISTERED_COPPA'" : '';

			$sql = 'SELECT group_id
				FROM ' . GROUPS_TABLE . '
				WHERE group_type = ' . GROUP_SPECIAL . "
				$sql_and";
			$result = $db->sql_query($sql);

			$group_id = $db->sql_fetchrowset($result);

			$db->sql_freeresult($result);
		}
		
		// Map usernames to ids and vice versa
		if ($usernames)
		{
			$username = explode("\n", $usernames);
		}
		unset($usernames);

		if (sizeof($username) && !sizeof($user_id))
		{
			user_get_id_name($user_id, $username);

			if (!sizeof($user_id))
			{
				trigger_error($user->lang['SELECTED_USER_NOT_EXIST'] . adm_back_link($this->u_action), E_USER_WARNING);
			}
		}
		unset($username);
		
		$form_name = 'acp_newsletter_perm';
		add_form_key($form_name);

		$this->permission_dropdown = array('f_');
		$permission_victim = array('newsletters', 'usergroup');

		$template->assign_vars(array(
			'L_TITLE'		=> $user->lang[$this->page_title],
			'L_EXPLAIN'		=> $user->lang[$this->page_title . '_EXPLAIN'])
		);

		switch ($action)
		{
			case 'delete':

				if (!check_form_key($form_name))
				{
					trigger_error($user->lang['FORM_INVALID']. adm_back_link($this->u_action), E_USER_WARNING);
				}
				// All users/groups selected?
				$all_users = (isset($_POST['all_users'])) ? true : false;
				$all_groups = (isset($_POST['all_groups'])) ? true : false;

				if ($all_users || $all_groups)
				{
					$items = newsletter_retrieve_defined_leader_groups($newsletter_id);

					if ($all_users && sizeof($items['user_ids']))
					{
						$user_id = $items['user_ids'];
					}
					else if ($all_groups && sizeof($items['group_ids']))
					{
						$group_id = $items['group_ids'];
					}
				}

				if (sizeof($user_id) || sizeof($group_id))
				{
					remove_permissions($user_id, $group_id, $newsletter_id, $this->u_action . '&amp;newsletter_id=' . $newsletter_id);
				}
				else
				{
					trigger_error($user->lang['NO_USER_GROUP_SELECTED'] . adm_back_link($this->u_action), E_USER_WARNING);
				}

			break;

			case 'add':

				if (!check_form_key($form_name))
				{
					trigger_error($user->lang['FORM_INVALID']. adm_back_link($this->u_action), E_USER_WARNING);
				}
				if (sizeof($user_id) || sizeof($group_id))
				{
					add_permissions($user_id, $group_id, $newsletter_id, $this->u_action . '&amp;newsletter_id=' . $newsletter_id);
				}
				else
				{
					trigger_error($user->lang['NO_USER_GROUP_SELECTED'] . adm_back_link($this->u_action), E_USER_WARNING);
				}

			break;

		}

		if (!$action)
		{
			if ($newsletter_id)
			{
				$newsletter_leaders_list = $newsletter_leaders = array();

				$sql = 'SELECT newsletter_name, newsletter_type FROM ' . NEWSLETTER_TABLE . '
					WHERE newsletter_id = ' . $newsletter_id;
				$result = $db->sql_query($sql);
				$newsletter_data = $db->sql_fetchrow($result);
				$db->sql_freeresult($result);

				$template->assign_vars(array(
					'S_SELECT_LEADERGROUP'		=> true,
					'S_NEWSLETTER_NAME'			=> true,
					'NEWSLETTER_NAME'			=> $newsletter_data['newsletter_name'],
				));

				//select newsletter_leaders
				if ($newsletter_data['newsletter_type'] != NEWSLETTER_BOARD)
				{
					$sql_array = array(
						'SELECT'	=> 'u.user_id',
						'FROM' => array(USERS_TABLE => 'u'),
						'WHERE' => 'au.forum_id = ' . $newsletter_id . " AND ao.auth_option = 'n_leader'",
						'LEFT_JOIN' => array(
							array(
								'FROM'	=> array(ACL_USERS_TABLE => 'au'),
								'ON'	=> 'u.user_id = au.user_id'
							),
							array(
								'FROM'	=> array(ACL_OPTIONS_TABLE => 'ao'),
								'ON'	=> 'au.auth_option_id = ao.auth_option_id'
							)
						)
					);

					$sql = $db->sql_build_query('SELECT_DISTINCT', $sql_array);

					$result = $db->sql_query($sql);

					while ($row = $db->sql_fetchrow($result))
					{
					$newsletter_leaders[] = $row['user_id'];
					}
					$db->sql_freeresult($result);

					$newsletter_leaders_list = make_newsletter_leaders_select($newsletter_leaders);

					// Build newsletter leader ptions
					$s_newsletter_leader_options = '';
					if ($newsletter_leaders_list)
					{
						foreach ($newsletter_leaders_list as $n_id => $n_row)
						{
							$s_newsletter_leader_options .= '<option value="' . $n_id . '">' . $n_row['username'] . '</option>';
						}
					}

					$template->assign_vars(array(
						'S_CAN_SELECT_LEADER'			=> true,
						'S_DEFINED_USER_OPTIONS'		=> $s_newsletter_leader_options,
						'S_NEWSLETTER_OPTIONAL'			=> ($newsletter_data['newsletter_type'] == NEWSLETTER_OPTIONAL) ? true : false,
						'U_FIND_USERNAME'				=> append_sid("{$phpbb_root_path}memberlist.$phpEx", 'mode=searchuser&amp;form=select_victim&amp;field=username&amp;select_single=true'),
						'U_ACTION'						=> $this->u_action . '&amp;newsletter_id=' . $newsletter_id
					));
				}

				else
				{
					$template->assign_vars(array(
						'S_NEWSLETTER_BOARD'		=> true,
						'S_CAN_NOT_SELECT_LEADER'	=> true,
					));
				}

				// select newsletter groups
				if ($newsletter_data['newsletter_type'] == NEWSLETTER_GROUP)
				{
					$sql = 'SELECT * FROM ' . NEWSLETTER_GROUPS_TABLE . '
						WHERE newsletter_id = ' . $newsletter_id;
					$result = $db->sql_query($sql);
					$newsletter_groups = $db->sql_fetchrow($result);
					$db->sql_freeresult($result);

					// Build newsletter groups options
					$s_newsletter_groups_options = '';

					if ($newsletter_groups)
					{
						$newsletter_groups_list = make_newsletter_groups_select($newsletter_groups);
						foreach ($newsletter_groups_list as $n_id => $n_row)
						{
							$s_newsletter_groups_options .= '<option value="' . $n_id . '"' . (($n_row['selected']) ? ' selected="selected"' : '') . '>' . $n_row['group_name'] . '</option>';
						}
					}

					$template->assign_vars(array(
						'S_CAN_SELECT_GROUP'			=> true,
						'S_NEWSLETTER_GROUPS_OPTIONS'	=> $s_newsletter_groups_options,
						'S_NEWSLETTER_GROUP'			=> true,
						'U_ACTION'						=> $this->u_action . '&amp;newsletter_id=' . $newsletter_id
					));
				}

				else
				{
					$template->assign_vars(array(
						'S_CAN_NOT_SELECT_GROUP'	=> true,
					));
				}

				$all_users = (isset($_POST['all_users'])) ? true : false;
				$all_groups = (isset($_POST['all_groups'])) ? true : false;
				if ((sizeof($user_id) && !$all_users) || (sizeof($group_id) && !$all_groups))
				{
					if (sizeof($user_id))
					{
						$this->check_existence('user', $user_id);
					}

					if (sizeof($group_id))
					{
						$this->check_existence('group', $group_id);
					}

					continue 2;
				}

				// Now we check the users... because the "all"-selection is different here (all defined users/groups)
				$items = newsletter_retrieve_defined_leader_groups($newsletter_id);

				if ($all_users && sizeof($items['user_ids']))
				{
					$user_id = $items['user_ids'];
					continue 2;
				}

				if ($all_groups && sizeof($items['group_ids']))
				{
					$group_id = $items['group_ids'];
					continue 2;
				}

				// Setting permissions screen
				$s_hidden_fields = build_hidden_fields(array(
					'user_id'		=> $user_id,
					'group_id'		=> $group_id,
					'newsletter_id'		=> $newsletter_id)
				);

				$template->assign_vars(array(
					'S_DEFINED_GROUP_OPTIONS'	=> $items['group_ids_options'],
					'S_ADD_GROUP_OPTIONS'		=> group_select_options(false, $items['group_ids'], (($user->data['user_type'] == USER_FOUNDER) ? false : 0)),
					'S_HIDDEN_FIELDS'			=> $s_hidden_fields,
					'U_ACTION'					=> $this->u_action . '&amp;newsletter_id=' . $newsletter_id,
				));

			}

			else
			{
				$newsletter_list = make_newsletter_select(false);

				// Build newsletter options
				$s_newsletter_options = '';
				foreach ($newsletter_list as $n_id => $n_row)
				{
					$s_newsletter_options .= '<option value="' . $n_id . '"' . (($n_row['selected']) ? ' selected="selected"' : '') . '>' . $n_row['newsletter_name'] . '</option>';
				}

				$template->assign_vars(array(
					'S_SELECT_VICTIM'			=> true,
					'S_SELECT_NEWSLETTER'		=> true,
					'S_NEWSLETTER_OPTIONS'		=> $s_newsletter_options,
					'U_ACTION'					=> $this->u_action
				));

			}

		}

	}

}

?>