<?php
/** 
*
* @package Multiple Newsletters Add On
* @version $Id: functions.php, v 1.004 2010/08/21 Martin Truckenbrodt Exp$
* @copyright (c) 2009 phpBB Group 
* @license http://opensource.org/licenses/gpl-license.php GNU Public License 
*
*/

if (!defined('IN_PHPBB'))
{
	exit;
}

/**
* Checks newsletter view permission
**/
function newsletter_is_viewable($user_id = 0, $newsletter_id = 0, $newsletter_public = NEWSLETTER_CLOSED)
{
	global $auth, $user, $db;

	$user_id = (int) $user_id;
	$newsletter_id = (int) $newsletter_id;

	if ($user->data['user_type'] == USER_FOUNDER || $auth->acl_get('a_newsletter') || newsletter_leader_status($user_id, $newsletter_id))
	{
		return true;
	}
	elseif ($newsletter_public == NEWSLETTER_ANONYMOUS)
	{
		return true;
	}
	elseif ($newsletter_public == NEWSLETTER_REGISTERED)
	{
		if ($user->data['user_id'] == ANONYMOUS)
		{
			return false;
		}
		else
		{
			return true;
		}
	}
	elseif ($newsletter_public == NEWSLETTER_CLOSED)
	{
		$sql = 'SELECT newsletter_type, newsletter_lang FROM ' . NEWSLETTER_TABLE . '
			WHERE newsletter_id = ' . $newsletter_id;
		$result = $db->sql_query($sql);
		$row = $db->sql_fetchrow($result);
		$db->sql_freeresult($result);
		if ($row['newsletter_lang'] && $row['newsletter_lang'] != $user->data['user_lang'])
		{
			return false;
		}
		else
		{
			if (newsletter_user_status($user_id, $newsletter_id, $row['newsletter_type'], $row['newsletter_lang']))
			{
				return true;
			}
			else
			{
				return false;
			}
		}
	}
	else
	{
		return false;
	}
}

/**
* Checks for user staus
**/
function newsletter_user_status($user_id = 0, $newsletter_id = 0, $newsletter_type = NEWSLETTER_BOARD, $newsletter_lang = '')
{
	global $auth, $user, $db, $phpbb_root_path, $phpEx;

	$user_id = (int) $user_id;
	$newsletter_id = (int) $newsletter_id;

	if (!$user_id || $user_id == ANONYMOUS || !$newsletter_id)
	{
		return false;
	}
	elseif ($user->data['user_type'] == USER_FOUNDER || $auth->acl_get('a_newsletter') || newsletter_leader_status($user_id, $newsletter_id))
	{
		return true;
	}
	else
	{
		if ($newsletter_type == NEWSLETTER_BOARD && ($newsletter_lang == $user->data['user_lang'] || !$newsletter_lang))
		{
			return true;
		}
		elseif ($newsletter_type == NEWSLETTER_OPTIONAL)
		{
			$sql = 'SELECT user_id FROM ' . NEWSLETTER_USERS_TABLE . '
				WHERE user_id = ' . $user_id . '
				AND newsletter_id = ' . $newsletter_id;
			$result = $db->sql_query($sql);
			$row = $db->sql_fetchrow($result);
			$db->sql_freeresult($result);
			if ($row['user_id'])
			{
				return true;
			}
			else
			{
				return false;
			}
		}
		elseif ($newsletter_type == NEWSLETTER_GROUP)
		{
			if (!function_exists('group_memberships'))
			{
				include($phpbb_root_path . 'includes/functions_user.' . $phpEx);
			}

			$group_id_ary = array();

			$sql = 'SELECT group_id FROM . ' . NEWSLETTER_GROUPS_TABLE . '
				WHERE newsletter_id = ' . $newsletter_id;
			$result = $db->sql_query($sql);
			$group_id_ary = $db->sql_fetchrow($result);
			$db->sql_freeresult($result);
			if ($group_id_ary)
			{
				if (group_memberships($group_id_ary, $user_id, true))
				{
					return true;
				}
				else
				{
					return false;
				}
			}
			else
			{
				return false;
			}
		}
		else
		{
			return false;
		}
	}
}

/**
* Checks for leader/moderator status
**/
function newsletter_leader_status($user_id = 0, $newsletter_id = 0)
{
	global $auth, $user, $db;

	$user_id = (int) $user_id;
	$newsletter_id = (int) $newsletter_id;

	if (!$user_id || !$newsletter_id || $user_id == ANONYMOUS)
	{
		return false;
	}
	elseif ($user->data['user_type'] == USER_FOUNDER || $auth->acl_get('a_newsletter'))
	{
		return true;
	}
	else
	{
		$sql_array = array(
			'SELECT'	=> 'au.user_id',
				'FROM'	=> array(ACL_USERS_TABLE => 'au'),
			'WHERE' => 'au.forum_id = ' . $newsletter_id . " AND ao.auth_option = 'n_leader' AND au.user_id = " . $user_id,
			'LEFT_JOIN' => array(
				array(
					'FROM'	=> array(ACL_OPTIONS_TABLE => 'ao'),
					'ON'	=> 'au.auth_option_id = ao.auth_option_id'
				)
			)
		);

		$sql = $db->sql_build_query('SELECT_DISTINCT', $sql_array);

		$result = $db->sql_query($sql);

		if ($db->sql_fetchrow($result))
		{
			$db->sql_freeresult($result);
			return true;
		}
		else
		{
			$db->sql_freeresult($result);
			return false;
		}
	}
}

/**
* Get newsletter subscribtion status
**/
function newslettter_status_display($user_id = 0, $newsletter_id = 0, $newsletter_type = NEWSLETTER_BOARD, $newsletter_lang = false)
{
	global $auth, $user, $db, $phpbb_root_path, $phpEx;

	$user_id = (int) $user_id;
	$newsletter_id = (int) $newsletter_id;

	if (!$newsletter_id)
	{
		trigger_error('NEWSLETTER_NO_NEWSLETTER');
	}
	if ($user->data['user_type'] == USER_FOUNDER || $auth->acl_get('a_newsletter') || newsletter_leader_status($user_id, $newsletter_id))
	{
		return array('lang' => $user->lang['NEWSLETTER_IS_LEADER'], 'url' => append_sid("{$phpbb_root_path}ucp.$phpEx?i=newsletter&amp;mode=newsletters"));
	}
	elseif ($user_id == ANONYMOUS)
	{
		return array('lang' => $user->lang['LOGIN'], 'url' => append_sid("{$phpbb_root_path}ucp.$phpEx?mode=login"));
	}
	elseif ($user->data['user_type'] == USER_IGNORE || $user->data['user_type'] == USER_INACTIVE)
	{
		return array('lang' => $user->lang['NEWSLETTER_IS_NOT_SUBSCRIBED'], 'url' => append_sid("{$phpbb_root_path}ucp.$phpEx?i=newsletter&amp;mode=newsletters"));
	}
	elseif ($user->data['user_type'] == USER_NORMAL)
	{
		if ($newsletter_type == NEWSLETTER_BOARD && ($newsletter_lang == $user->data['user_lang'] || ($newsletter_lang == false)))
		{
			return array('lang' => $user->lang['NEWSLETTER_IS_SUBSCRIBED'], 'url' => append_sid("{$phpbb_root_path}ucp.$phpEx?i=newsletter&amp;mode=newsletters"));
		}
		elseif ($newsletter_type == NEWSLETTER_OPTIONAL)
		{
			$sql = 'SELECT user_id FROM ' . NEWSLETTER_USERS_TABLE . '
				WHERE user_id = ' . $user_id . '
				AND newsletter_id = ' . $newsletter_id;
			$result = $db->sql_query($sql);
			$row = $db->sql_fetchrow($result);
			$db->sql_freeresult($result);

			if ($row['user_id'])
			{
				return array('lang' => $user->lang['NEWSLETTER_IS_SUBSCRIBED'], 'url' => append_sid("{$phpbb_root_path}ucp.$phpEx?i=newsletter&amp;mode=newsletters"));
			}
			else
			{
				return array('lang' => $user->lang['NEWSLETTER_IS_NOT_SUBSCRIBED'], 'url' => append_sid("{$phpbb_root_path}ucp.$phpEx?i=newsletter&amp;mode=newsletters"));
			}
		}
		elseif ($newsletter_type == NEWSLETTER_GROUP)
		{
			if (!function_exists('group_memberships'))
			{
				include($phpbb_root_path . 'includes/functions_user.' . $phpEx);
			}
			
			$sql = 'SELECT group_id FROM . ' . NEWSLETTER_GROUPS_TABLE . '
				WHERE newsletter_id = ' . $newsletter_id;
			$result = $db->sql_query($sql);
			$group_id_ary = $db->sql_fetchrow($result);
			$db->sql_freeresult($result);
			
			if (group_memberships($group_id_ary, $user_id, true))
			{
				return array('lang' => $user->lang['NEWSLETTER_IS_SUBSCRIBED'], 'url' => append_sid("{$phpbb_root_path}ucp.$phpEx?i=newsletter&amp;mode=newsletters"));
			}
			else
			{
				return array('lang' => $user->lang['NEWSLETTER_IS_NOT_SUBSCRIBED'], 'url' => append_sid("{$phpbb_root_path}ucp.$phpEx?i=newsletter&amp;mode=newsletters"));
			}
		}
	}
}

/**
* Get timestamp of last sent e-mail
**/
function newsletter_last_email($newsletter_id = 0)
{
	global $db, $phpEx;

	$newsletter_id = (int) $newsletter_id;

	$sql = 'SELECT email_timestamp FROM ' . NEWSLETTER_EMAIL_TABLE . '
		WHERE newsletter_id = ' . $newsletter_id . ' ORDER BY email_timestamp DESC';
	$result = $db->sql_query($sql);
	$row = $db->sql_fetchrow($result);
	$db->sql_freeresult($result);
	
	return $row['email_timestamp'];
}

/**
* Builds the e-mail sender username and hyperlink
**/
function build_email_sender($email_id = 0, $user_id = 0)
{
	global $user, $db, $phpEx;

	$email_id = (int) $email_id;
	$user_id = (int) $user_id;

	$server_url = generate_board_url();
	
	if ((!$user_id) && ($email_id))
	{
		$sql = 'SELECT user_id FROM ' . NEWSLETTER_EMAIL_TABLE . '
			WHERE email_id = ' . $email_id;
		$result = $db->sql_query($sql);
		$row = $db->sql_fetchrow($result);
		$db->sql_freeresult($result);
		$user_id = (int) $row['user_id'];
	}
	if (!$user_id)
	{
		trigger_error('NO_USER');
	}
	$sql = 'SELECT username, user_colour FROM ' . USERS_TABLE . '
		WHERE user_id = ' . $user_id;
	$result = $db->sql_query($sql);
	$row = $db->sql_fetchrow($result);
	$db->sql_freeresult($result);
	
	return get_username_string('full', $user_id, $row['username'], $row['user_colour'], false, $server_url . '/memberlist.' . $phpEx . '?mode=viewprofile');
}

/**
* Builds the e-mail sender username and hyperlink for plain use
**/
function build_email_sender_plain($email_id = 0, $user_id = 0)
{
	global $user, $db, $phpEx;

	$email_id = (int) $email_id;
	$user_id = (int) $user_id;

	$server_url = generate_board_url();

	if ((!$user_id) && ($email_id))
	{
		$sql = 'SELECT user_id FROM ' . NEWSLETTER_EMAIL_TABLE . '
			WHERE email_id = ' . $email_id;
		$result = $db->sql_query($sql);
		$row = $db->sql_fetchrow($result);
		$db->sql_freeresult($result);
		$user_id = (int) $row['user_id'];
	}
	if (!$user_id)
	{
		trigger_error('NO_USER');
	}
	$sql = 'SELECT username FROM ' . USERS_TABLE . '
		WHERE user_id = ' . $user_id;
	$result = $db->sql_query($sql);
	$row = $db->sql_fetchrow($result);
	$db->sql_freeresult($result);
	
	return $row['username'] . "<br />" . $server_url . '/memberlist.' . $phpEx . '?mode=viewprofile&amp;u=' . $user_id;
}

/**
* Builds the e-mail sender signature
**/
function build_email_sender_signature($email_id = 0, $user_id = 0)
{
	global $user, $db;

	$email_id = (int) $email_id;
	$user_id = (int) $user_id;

	if ((!$user_id) && ($email_id))
	{
		$sql = 'SELECT user_id FROM ' . NEWSLETTER_EMAIL_TABLE . '
			WHERE email_id = ' . $email_id;
		$result = $db->sql_query($sql);
		$row = $db->sql_fetchrow($result);
		$db->sql_freeresult($result);
		$user_id = (int) $row['user_id'];
	}
	if (!$user_id)
	{
		trigger_error('NO_USER');
	}
	$sql = 'SELECT user_sig, user_sig_bbcode_uid, user_sig_bbcode_bitfield FROM ' . USERS_TABLE . '
		WHERE user_id = ' . $user_id;
	$result = $db->sql_query($sql);
	$row = $db->sql_fetchrow($result);
	$db->sql_freeresult($result);
	
	return nl2br(generate_text_for_display($row['user_sig'], $row['user_sig_bbcode_uid'], $row['user_sig_bbcode_bitfield'], 7));
}

/**
* Parse text for plain/text email and preview
*/
function text2plain($text = '', $preview = false, $from_bbcode = false)
{
	if (!$preview || $from_bbcode)
	{
		// convert HTML anchor tags to plain URLs -> convert HTML IMG tags to plain URLs -> replace HTML breaks with plain line feed
		// -> remove (all) HTML tags -> replace line 
		$text = hyperlink2plain($text);
		$text = img2plain($text);
		$text = br2nl($text);
		$text = strip_tags($text);
	}

	if ($preview)
	{
		// create HTML anchor tags around URLs -> replace plain line feeds with HTML breaks
		$text = preg_replace("/(https?:\/\/)([^\s]+)/", '<a href="$1$2">$1$2</a>', $text);
		$text = preg_replace("/(mailto:)([^\s]+)/", '<a href="$1$2">$2</a>', $text);
		$text = nl2br($text);
	}

	return $text;
}

/**
* Replaces the HTML hyperlink anchor tag with the URL contained in href
**/
function hyperlink2plain($text)
{
	$search  = array(" class=\"postlink\"", " class=\"postlink-local\"");
	$replacement  = array("", "");

	$text = str_replace($search, $replacement, $text);

	$text = htmlspecialchars_decode($text);

	$text = preg_replace('#<a href="((https?://|mailto:)[^"]+)">(.*?)</a>#', ' \\1 ', $text);

	$text = str_replace("<br /> ", "<br />", $text);
	$text = str_replace(" <br /> ", "<br />", $text);

	return $text;
}

/**
* Replaces the img tag with the URL contained in src
**/
function img2plain($text)
{
	global $user;

	$text = str_replace(" alt=\"" . $user->lang['IMAGE'] . "\"", "", $text);

	$text = preg_replace('#<img src="(https?://[^"]+)" />#', ' \\1 ', $text);

	$text = str_replace("<br /> ", "<br />", $text);
	$text = str_replace(" <br /> ", "<br />", $text);

	return $text;
}

/**
* replace <br /> with text line feed
**/
function br2nl($text)
{
	$text = str_replace("<br />","\n",$text);

	return $text;
}

/**
* show reset and submit button on includes/ucp/ucp_newsletter.php => manage subscriptions
**/
function newsletter_ucp_buttons()
{
	global $db, $auth, $user;

	if ($user->data['user_type'] == USER_FOUNDER || $auth->acl_get('a_newsletter'))
	{
		return false;
	}
	$newsletter_ids = array();
	$sql = 'SELECT newsletter_id FROM ' . NEWSLETTER_TABLE . '
		WHERE newsletter_type = ' . NEWSLETTER_OPTIONAL;
	$result = $db->sql_query($sql);
	while ($row = $db->sql_fetchrow($result))
	{
		$newsletter_ids[] = $row['newsletter_id'];
	}
	$db->sql_freeresult($result);

	if (!$newsletter_ids)
	{
		return false;
	}
	else
	{
		$sql_array = array(
			'SELECT'	=> 'au.forum_id',
			'FROM' => array(ACL_USERS_TABLE => 'au'),
			'WHERE' => $db->sql_in_set('au.forum_id', $newsletter_ids) . ' AND au.user_id = ' . $user->data['user_id'] . " AND ao.auth_option = 'n_leader'",
			'LEFT_JOIN' => array(
				array(
					'FROM'	=> array(ACL_OPTIONS_TABLE => 'ao'),
					'ON'	=> 'au.auth_option_id = ao.auth_option_id'
				)
			)
		);
		$sql = $db->sql_build_query('SELECT', $sql_array);
		$result = $db->sql_query($sql);

		if ($db->sql_fetchrow($result))
		{
			$db->sql_freeresult($result);
			return false;
		}
		else
		{
			$db->sql_freeresult($result);
			return true;
		}

	}
}

?>