<?php
/** 
*
* @package Multiple Newsletters Add On
* @version $Id: functions_admin.php, v 1.004 2010/08/20 Martin Truckenbrodt Exp$
* @copyright (c) 2009 phpBB Group 
* @license http://opensource.org/licenses/gpl-license.php GNU Public License 
*
*/

if (!defined('IN_PHPBB'))
{
	exit;
}

/**
* Get newsletter details
*/
function get_newsletter_info($newsletter_id = 0)
{
	global $db;
		$sql = 'SELECT *
		FROM ' . NEWSLETTER_TABLE . '
		WHERE newsletter_id = ' . $newsletter_id;
	$result = $db->sql_query($sql);
	$row = $db->sql_fetchrow($result);
	$db->sql_freeresult($result);

	return $row;
}

/**
* Update newsletter data
*/
function update_newsletter_data(&$newsletter_data)
{
	global $db, $user, $cache, $config;

	$errors = array();

	if (!$newsletter_data['newsletter_name'])
	{
		$errors[] = $user->lang['NEWSLETTER_NAME_EMPTY'];
	}

	if (utf8_strlen($newsletter_data['newsletter_desc']) > $config['max_sig_chars'])
	{
		$errors[] = $user->lang['NEWSLETTER_DESC_TOO_LONG'];
	}

	if (utf8_strlen($newsletter_data['newsletter_footer']) > $config['max_sig_chars'])
	{
		$errors[] = $user->lang['NEWSLETTER_FOOTER_TOO_LONG'];
	}

	// Unset data that are not database fields
	$newsletter_data_sql = $newsletter_data;

	// What are we going to do tonight Brain? The same thing we do everynight,
	// try to take over the world ... or decide whether to continue update
	// and if so, whether which groups and users we have to remove from which tables
	if (sizeof($errors))
	{
		return $errors;
	}

	if (!isset($newsletter_data_sql['newsletter_id']))
	{
		// no newsletter_id means we're creating a new newsletter
		unset($newsletter_data_sql['type_action']);

		$sql = 'SELECT MAX(right_id) AS right_id
			FROM ' . NEWSLETTER_TABLE;
		$result = $db->sql_query($sql);
		$row = $db->sql_fetchrow($result);
		$db->sql_freeresult($result);

		$newsletter_data_sql['left_id'] = $row['right_id'] + 1;
		$newsletter_data_sql['right_id'] = $row['right_id'] + 2;

		$sql = 'INSERT INTO ' . NEWSLETTER_TABLE . ' ' . $db->sql_build_array('INSERT', $newsletter_data_sql);
		$db->sql_query($sql);

		$newsletter_data['newsletter_id'] = $db->sql_nextid();

		add_log('admin', 'LOG_NEWSLETTER_ADD', $newsletter_data['newsletter_name']);
	}
	else
	{
		$sql = 'SELECT newsletter_id, newsletter_type FROM ' . NEWSLETTER_TABLE . '
			WHERE newsletter_id = ' . $newsletter_data_sql['newsletter_id'];
		$result = $db->sql_query($sql);
		$row = $db->sql_fetchrow($result);
		$db->sql_freeresult($result);

		//purge old data from NEWSLETTER_USERS_TABLE, NEWSLETTER_GROUPS_TABLE OR ACL_USERS_TABLE if not more needed for new newsletter_type
		if ($row['newsletter_type'] != $newsletter_data_sql['newsletter_type'] && $row['newsletter_type'] != NEWSLETTER_BOARD)
		{
			if ($row['newsletter_type'] == NEWSLETTER_OPTIONAL)
			{
				$sql = 'DELETE FROM ' . NEWSLETTER_USERS_TABLE . '
					WHERE newsletter_id = ' . (int) $row['newsletter_id'];
				$db->sql_query($sql);
			}
			else if ($row['newsletter_type'] == NEWSLETTER_GROUP)
			{
				$sql = 'DELETE FROM ' . NEWSLETTER_GROUPS_TABLE . '
					WHERE newsletter_id = ' . (int) $row['newsletter_id'];
				$db->sql_query($sql);
			}
			if ($newsletter_data_sql['newsletter_type'] == NEWSLETTER_BOARD)
			{
				$sql = 'SELECT auth_option_id FROM ' . ACL_OPTIONS_TABLE . "
					WHERE auth_option = 'n_leader'";
				$result = $db->sql_query($sql);
				$option_row = $db->sql_fetchrow($result);
				$db->sql_freeresult($result);

				$sql = 'DELETE FROM ' . ACL_USERS_TABLE . '
					WHERE forum_id = ' . (int) $row['newsletter_id'] . ' AND auth_option_id = ' . (int) $option_row['auth_option_id'];
				$db->sql_query($sql);
			}
		}

		if (sizeof($errors))
		{
			return $errors;
		}

		// Setting the newsletter id to the newsletter id is not really received well by some dbs. ;)
		$newsletter_id = $newsletter_data_sql['newsletter_id'];
		unset($newsletter_data_sql['newsletter_id']);

		$sql = 'UPDATE ' . NEWSLETTER_TABLE . '
			SET ' . $db->sql_build_array('UPDATE', $newsletter_data_sql) . '
			WHERE newsletter_id = ' . $newsletter_id;
		$db->sql_query($sql);

		// Add it back
		$newsletter_data['newsletter_id'] = $newsletter_id;

		add_log('admin', 'LOG_NEWSLETTER_EDIT', $newsletter_data['newsletter_name']);
	}

	return $errors;
}

/**
* Remove complete newsletter
*/
function delete_newsletter($newsletter_id = 0)
{
	global $db, $user, $cache;

	$sql = 'SELECT newsletter_name, left_id, right_id FROM ' . NEWSLETTER_TABLE . '
		WHERE newsletter_id= ' . $newsletter_id;
	$result = $db->sql_query($sql);
	$newsletter_data = $db->sql_fetchrow($result);
	$db->sql_freeresult($result);

	$newsletter_data['left_id'] = (int) $newsletter_data['left_id'];
	$newsletter_data['right_id'] = (int) $newsletter_data['right_id'];

	$errors = array();

	$sql = 'DELETE FROM ' . NEWSLETTER_TABLE . "
		WHERE newsletter_id = $newsletter_id";
	$db->sql_query($sql);

	$sql = 'DELETE FROM ' . NEWSLETTER_EMAIL_TABLE . "
		WHERE newsletter_id = $newsletter_id";
	$db->sql_query($sql);

	$sql = 'DELETE FROM ' . NEWSLETTER_GROUPS_TABLE  . "
		WHERE newsletter_id = $newsletter_id";
	$db->sql_query($sql);

	$sql = 'DELETE FROM ' . NEWSLETTER_USERS_TABLE . "
		WHERE newsletter_id = $newsletter_id";
	$db->sql_query($sql);

	$sql = 'SELECT auth_option_id FROM ' . ACL_OPTIONS_TABLE . "
		WHERE auth_option = 'n_leader'";
	$result = $db->sql_query($sql);
	$row = $db->sql_fetchrow($result);
	$db->sql_freeresult($result);

	$sql = 'DELETE FROM ' . ACL_USERS_TABLE . "
		WHERE forum_id = $newsletter_id AND auth_option_id = ". $row['auth_option_id'];
	$db->sql_query($sql);

	// Resync tree
	$diff = 2;
	$sql = 'UPDATE ' . NEWSLETTER_TABLE . "
		SET right_id = right_id - $diff
		WHERE left_id < {$newsletter_data['right_id']} AND right_id > {$newsletter_data['right_id']}";
	$db->sql_query($sql);

	$sql = 'UPDATE ' . NEWSLETTER_TABLE . "
		SET left_id = left_id - $diff, right_id = right_id - $diff
		WHERE left_id > {$newsletter_data['right_id']}";
	$db->sql_query($sql);

	add_log('admin', 'LOG_NEWSLETTER_DELETE', $newsletter_data['newsletter_name']);

	return $errors;
}

/**
* Move newsletter position by $steps up/down
*/
function move_newsletter_by($newsletter_row, $action = 'move_up')
{
	global $db;

	/**
	* Fetch all the siblings between the module's current spot
	* and where we want to move it to. If there are less than $steps
	* siblings between the current spot and the target then the
	* module will move as far as possible
	*/
	$sql = 'SELECT newsletter_id, newsletter_name, left_id, right_id FROM ' . NEWSLETTER_TABLE . '
		WHERE ' . (($action == 'move_up') ? "right_id < {$newsletter_row['right_id']} ORDER BY right_id DESC" : "left_id > {$newsletter_row['left_id']} ORDER BY left_id ASC");

	$result = $db->sql_query_limit($sql, 1);

	$target = array();
	$target = $db->sql_fetchrow($result);
	$db->sql_freeresult($result);

	if (!sizeof($target))
	{
		// The newsletter is already on top or bottom
		return false;
	}

	/**
	* $left_id and $right_id define the scope of the nodes that are affected by the move.
	* $diff_up and $diff_down are the values to substract or add to each node's left_id
	* and right_id in order to move them up or down.
	* $move_up_left and $move_up_right define the scope of the nodes that are moving
	* up. Other nodes in the scope of ($left_id, $right_id) are considered to move down.
	*/
	$newsletter_row['left_id'] = (int) $newsletter_row['left_id'];
	$newsletter_row['right_id'] = (int) $newsletter_row['right_id'];

	if ($action == 'move_up')
	{
		$left_id = $target['left_id'];
		$right_id = $newsletter_row['right_id'];

		$diff_up = $newsletter_row['left_id'] - $target['left_id'];
		$diff_down = $newsletter_row['right_id'] + 1 - $newsletter_row['left_id'];

		$move_up_left = $newsletter_row['left_id'];
		$move_up_right = $newsletter_row['right_id'];
	}
	else
	{
		$left_id = $newsletter_row['left_id'];
		$right_id = $target['right_id'];

		$diff_up = $newsletter_row['right_id'] + 1 - $newsletter_row['left_id'];
		$diff_down = $target['right_id'] - $newsletter_row['right_id'];

		$move_up_left = $newsletter_row['right_id'] + 1;
		$move_up_right = $target['right_id'];
	}

	// Now do the dirty job
	$sql = 'UPDATE ' . NEWSLETTER_TABLE . "
		SET left_id = left_id + CASE
			WHEN left_id BETWEEN {$move_up_left} AND {$move_up_right} THEN -{$diff_up}
			ELSE {$diff_down}
		END,
		right_id = right_id + CASE
			WHEN right_id BETWEEN {$move_up_left} AND {$move_up_right} THEN -{$diff_up}
			ELSE {$diff_down}
		END
		WHERE
			left_id BETWEEN {$left_id} AND {$right_id}
			AND right_id BETWEEN {$left_id} AND {$right_id}";

	$db->sql_query($sql);

	return $target['newsletter_name'];
}

/**
* Pick a language, any language ...
*/
function newsletter_language_select($default = '')
{
	global $user, $db;

	$sql = 'SELECT lang_iso, lang_local_name
		FROM ' . LANG_TABLE . '
		ORDER BY lang_english_name';
	$result = $db->sql_query($sql);

	$lang_options = '';
	$selected = ($default == '') ? ' selected="selected"' : '';
	$lang_options .= '<option value=""' . $selected . '>' . $user->lang['NO_NEWSLETTER_LANG'] . '</option>';
	while ($row = $db->sql_fetchrow($result))
	{
		$selected = ($row['lang_iso'] == $default) ? ' selected="selected"' : '';
		$lang_options .= '<option value="' . $row['lang_iso'] . '"' . $selected . '>' . $row['lang_local_name'] . '</option>';
	}
	$db->sql_freeresult($result);

	return $lang_options;
}

/**
* Get already assigned leaders/groups
*/
function newsletter_retrieve_defined_leader_groups($newsletter_id = 0)
{
	global $db, $user;

	$sql_array = array(
		'SELECT'	=> 'u.username, u.username_clean, u.user_regdate, u.user_id',
		'FROM' => array(USERS_TABLE => 'u'),
		'WHERE' => 'au.forum_id = ' . $newsletter_id . " AND ao.auth_option = 'n_leader'",
		'LEFT_JOIN' => array(
			array(
				'FROM'	=> array(ACL_USERS_TABLE => 'au'),
				'ON'	=> 'u.user_id = au.user_id'
			),
			array(
				'FROM'	=> array(ACL_OPTIONS_TABLE => 'ao'),
				'ON'	=> 'au.auth_option_id = ao.auth_option_id'
			)
		),
		'ORDER_BY'	=> 'u.username_clean, u.user_regdate ASC'
	);

	$sql = $db->sql_build_query('SELECT_DISTINCT', $sql_array);

	$result = $db->sql_query($sql);

	$s_defined_user_options = '';
	$defined_user_ids = array();
	while ($row = $db->sql_fetchrow($result))
	{
		$s_defined_user_options .= '<option value="' . $row['user_id'] . '">' . $row['username'] . '</option>';
		$defined_user_ids[] = $row['user_id'];
	}
	$db->sql_freeresult($result);

	$sql = $db->sql_build_query('SELECT_DISTINCT', array(
		'SELECT'	=> 'g.group_type, g.group_name, g.group_id',

		'FROM'		=> array(
			GROUPS_TABLE		=> 'g',
			NEWSLETTER_GROUPS_TABLE	=> 'a'
		),

		'WHERE'		=> "a.newsletter_id = $newsletter_id
			AND g.group_id = a.group_id",

		'ORDER_BY'	=> 'g.group_type DESC, g.group_name ASC'
	));
	$result = $db->sql_query($sql);

	$s_defined_group_options = '';
	$defined_group_ids = array();
	while ($row = $db->sql_fetchrow($result))
	{
		$s_defined_group_options .= '<option' . (($row['group_type'] == GROUP_SPECIAL) ? ' class="sep"' : '') . ' value="' . $row['group_id'] . '">' . (($row['group_type'] == GROUP_SPECIAL) ? $user->lang['G_' . $row['group_name']] : $row['group_name']) . '</option>';
		$defined_group_ids[] = $row['group_id'];
	}
	$db->sql_freeresult($result);

	return array(
		'group_ids'			=> $defined_group_ids,
		'group_ids_options'	=> $s_defined_group_options,
		'user_ids'			=> $defined_user_ids,
		'user_ids_options'	=> $s_defined_user_options
	);
}

/**
* Remove permissions
*/
function remove_permissions(&$user_id, &$group_id, &$newsletter_id, $u_action)
{
	global $user, $db, $auth;

	// Check the permission setting again
	if (!$auth->acl_get('a_newsletter'))
	{
		trigger_error($user->lang['NO_AUTH_OPERATION'] . adm_back_link($this->u_action), E_USER_WARNING);
	}

	// User or group to be set?
	$ug_type = (sizeof($user_id)) ? 'user' : 'group';

	if ($ug_type == 'user')
	{
		$sql = "DELETE FROM " . ACL_USERS_TABLE . " WHERE ". $db->sql_in_set('user_id', $user_id) . " AND forum_id = " . (int) $newsletter_id;
		$result = $db->sql_query($sql, 600);
	}
	else if ($ug_type = 'group')
	{
		$sql = "DELETE FROM " . NEWSLETTER_GROUPS_TABLE . " WHERE " . $db->sql_in_set('group_id', $group_id) . " AND newsletter_id = " . (int) $newsletter_id;
		$result = $db->sql_query($sql, 600);
	}

	log_action('del', $ug_type, (($ug_type == 'user') ? $user_id : $group_id), (sizeof($newsletter_id) ? $newsletter_id : array(0 => 0)));

	trigger_error($user->lang['AUTH_UPDATED'] . adm_back_link($u_action));
}

/**
* Log permission changes
*/
function log_action($action, $ug_type, $ug_id = 0, $newsletter_id = 0)
{
	global $db, $user;

	if (!is_array($ug_id))
	{
		$ug_id = array($ug_id);
	}

	if (!is_array($newsletter_id))
	{
		$newsletter_id = array($newsletter_id);
	}

	// Logging ... first grab user or groupnames ...
	$sql = ($ug_type == 'group') ? 'SELECT group_name as name, group_type FROM ' . GROUPS_TABLE . ' WHERE ' : 'SELECT username as name FROM ' . USERS_TABLE . ' WHERE ';
	$sql .= $db->sql_in_set(($ug_type == 'group') ? 'group_id' : 'user_id', array_map('intval', $ug_id));
	$result = $db->sql_query($sql);

	$l_ug_list = '';
	while ($row = $db->sql_fetchrow($result))
	{
		$l_ug_list .= (($l_ug_list != '') ? ', ' : '') . ((isset($row['group_type']) && $row['group_type'] == GROUP_SPECIAL) ? '<span class="sep">' . $user->lang['G_' . $row['name']] . '</span>' : $row['name']);
	}
	$db->sql_freeresult($result);

	if ($newsletter_id[0] == 0)
	{
		add_log('admin', 'LOG_ACL_' . strtoupper($action) . '_' . strtoupper($ug_type) . '_' . strtoupper('n_'), $l_ug_list);
	}
	else
	{
		// Grab the newsletter details if non-zero newsletter_id
		$sql = 'SELECT newsletter_name
			FROM ' . NEWSLETTER_TABLE . '
			WHERE ' . $db->sql_in_set('newsletter_id', $newsletter_id);
		$result = $db->sql_query($sql);

		$l_newsletter_list = '';
		while ($row = $db->sql_fetchrow($result))
		{
			$l_newsletter_list .= (($l_newsletter_list != '') ? ', ' : '') . $row['newsletter_name'];
		}
		$db->sql_freeresult($result);

		add_log('admin', 'LOG_ACL_' . strtoupper($action) . '_' . strtoupper($ug_type) . '_' . strtoupper('n_'), $l_newsletter_list, $l_ug_list);
	}
}

/**
* Add permissions
*/
function add_permissions(&$user_id, &$group_id, $newsletter_id, $u_action)
{
	global $user, $db, $auth;

	// Check the permission setting again
	if (!$auth->acl_get('a_newsletter'))
	{
		trigger_error($user->lang['NO_AUTH_OPERATION'] . adm_back_link($this->u_action), E_USER_WARNING);
	}

	// User or group to be set?
	$ug_type = (sizeof($user_id)) ? 'user' : 'group';

	if ($ug_type == 'user')
	{
		$sql = 'SELECT auth_option_id FROM ' . ACL_OPTIONS_TABLE . "
			WHERE auth_option = 'n_leader'";
		$result = $db->sql_query($sql);
		$row = $db->sql_fetchrow($result);
		$auth_option_id = $row['auth_option_id'];
		$db->sql_freeresult($result);
		
		$table = ACL_USERS_TABLE;
		foreach ($user_id as $id)
		{
			$sql_ary[] = array(
				'user_id'			=> (int) $id,
				'forum_id'		=> (int) $newsletter_id,
				'auth_option_id'	=> (int) $auth_option_id
			);
		}
	}
	else if ($ug_type = 'group')
	{
		$table = NEWSLETTER_GROUPS_TABLE;
		foreach ($group_id as $id)
		{
			$sql_ary[] = array(
				'group_id'			=> (int) $id,
				'newsletter_id'		=> (int) $newsletter_id
			);
		}
	}

	$db->sql_multi_insert($table, $sql_ary);

	log_action('add', $ug_type, (($ug_type == 'user') ? $user_id : $group_id), (sizeof($newsletter_id) ? $newsletter_id : array(0 => 0)));

	trigger_error($user->lang['AUTH_UPDATED'] . adm_back_link($u_action));
}

/**
* Simple version of newsletter jumpbox
*/
function make_newsletter_select($select_id = false)
{
	global $db, $user, $auth;

	// This query is identical to the jumpbox one
	$sql = 'SELECT newsletter_id, newsletter_name, newsletter_type, left_id, right_id
		FROM ' . NEWSLETTER_TABLE . '
		ORDER BY left_id ASC';
	$result = $db->sql_query($sql, 600);

	$newsletter_list = array();

	while ($row = $db->sql_fetchrow($result))
	{
		// Include some more information...
		$selected = (is_array($select_id)) ? ((in_array($row['newsletter_id'], $select_id)) ? true : false) : (($row['newsletter_id'] == $select_id) ? true : false);
		$newsletter_list[$row['newsletter_id']] = array_merge(array('selected' => $selected), $row);
	}
	$db->sql_freeresult($result);

	return $newsletter_list;
}

/**
* Simple version of newsletter_leaders jumpbox
*/
function make_newsletter_leaders_select($select_id = false)
{
	global $db, $user, $auth;

	$newsletter_leaders_list = array();

	if ($select_id)
	{
		// This query is identical to the jumpbox one
		$sql = 'SELECT user_id, username
			FROM ' . USERS_TABLE . '
			WHERE ' . $db->sql_in_set('user_id', $select_id);
		$result = $db->sql_query($sql, 600);

		while ($row = $db->sql_fetchrow($result))
		{
			// Include some more information...
			$newsletter_leaders_list[$row['user_id']] = $row;
		}
		$db->sql_freeresult($result);
	}

	return $newsletter_leaders_list;
}

/**
* Simple version of newsletter_groups jumpbox
*/
function make_newsletter_groups_select($select_id = false)
{
	global $db, $user, $auth;

	// This query is identical to the jumpbox one
	$sql = 'SELECT group_id, group_name
		FROM ' . GROUPS_TABLE . '
		WHERE ' . $db->sql_in_set('group_id', $select_id);
	$result = $db->sql_query($sql, 600);

	$newsletter_groups = array();

	while ($row = $db->sql_fetchrow($result))
	{
		// Include some more information...
		$selected = (is_array($select_id)) ? ((in_array($row['group_id'], $select_id)) ? true : false) : (($row['group_id'] == $select_id) ? true : false);
		$newsletter_groups[$row['group_id']] = array_merge(array('selected' => $selected), $row);
	}
	$db->sql_freeresult($result);

	return $newsletter_groups;
}

/**
* delete newsletter email
**/
function delete_newsletter_email($email_id, $newsletter_id = 0, $user_id = 0)
{
	global $db, $user, $phpEx, $phpbb_root_path;

	$errors = array();

	if (newsletter_leader_status($user_id, $newsletter_id))
	{
		$s_hidden_fields = build_hidden_fields(array(
			'e'		=> $email_id,
			'n'		=> $newsletter_id,
			'mode'	=> 'delete')
		);

		if (confirm_box(true))
		{
			$sql = 'DELETE FROM ' . NEWSLETTER_EMAIL_TABLE . '
				WHERE email_id = ' . $email_id;
			$result = $db->sql_query($sql);
			$db->sql_freeresult($result);

			$meta_info = append_sid("{$phpbb_root_path}newsletter_archive.$phpEx", "n=$newsletter_id");

			meta_refresh(3, $meta_info);

			$message = $user->lang['NEWSLETTER_EMAIL_DELETED'] . '<br /><br />' . sprintf($user->lang['RETURN_NEWSLETTER'], '<a href="' . append_sid("{$phpbb_root_path}newsletter_archive.$phpEx", "n=$newsletter_id") . '">', '</a>');

			trigger_error($message);
		}
		else
		{
			confirm_box(false, $user->lang['NEWSLETTER_EMAIL_DELETE_CONFIRM'], $s_hidden_fields);
		}

	}
	else
	{
		trigger_error($user->lang['NEWSLETTER_USER_CANNOT_DELETE']);
	}
	return $errors;
}

?>