<?php 
/** 
*
* @package Multiple Newsletters MOD
* @version $Id: ucp_newsletter.php, v 1.006 2010/07/31 Martin Truckenbrodt Exp$
* @copyright (c) 2009 phpBB Group 
* @license http://opensource.org/licenses/gpl-license.php GNU Public License 
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

/**
* ucp_newsletter
* UCP Newslettter settings and management
* @package ucp
*/
class ucp_newsletter
{
	var $p_master;
	var $u_action;

	function ucp_main(&$p_master)
	{
		$this->p_master = &$p_master;
	}

	function main($id, $mode)
	{
		global $config, $db, $user, $auth, $template, $phpbb_root_path, $phpEx;

		include($phpbb_root_path . 'includes/newsletter/constants.'.$phpEx);
		include($phpbb_root_path . 'includes/newsletter/functions.'.$phpEx);

		$user->add_lang('mods/newsletter');

		$start		= request_var('start', 0);
		$submit = (isset($_POST['submit'])) ? true : false;
		$s_hidden_fields = '';

		switch ($mode)
		{
			case 'newsletters':

				$set_status = request_var('set', array(0 => 0));
				$set_newsletters = array_keys($set_status);

				if ($submit)
				{
					$sql = 'SELECT newsletter_id, newsletter_type, newsletter_lang FROM ' . NEWSLETTER_TABLE . '
						WHERE ' . $db->sql_in_set('newsletter_id', $set_newsletters);
					$result = $db->sql_query($sql);
					while ($newsletter_row = $db->sql_fetchrow($result))
					{
						if (!newsletter_leader_status($user->data['user_id'], $newsletter_row['newsletter_id']))
						{
							if ($set_status[$newsletter_row['newsletter_id']] && !newsletter_user_status($user->data['user_id'], $newsletter_row['newsletter_id'], $newsletter_row['newsletter_type'], $newsletter_row['newsletter_lang']))
							{
								$sql = 'INSERT INTO ' . NEWSLETTER_USERS_TABLE . '
									(user_id, newsletter_id) VALUES (' . (int) $user->data['user_id'] . ', ' . (int) $newsletter_row['newsletter_id'] . ')';
								$insert = $db->sql_query($sql);
							}
							else if (!$set_status[$newsletter_row['newsletter_id']] && newsletter_user_status($user->data['user_id'], $newsletter_row['newsletter_id'], $newsletter_row['newsletter_type'], $newsletter_row['newsletter_lang']))
							{
								$sql = 'DELETE FROM ' . NEWSLETTER_USERS_TABLE . '
									WHERE user_id = ' . (int) $user->data['user_id']  . '
									AND newsletter_id = ' . (int) $newsletter_row['newsletter_id'];
								$delete = $db->sql_query($sql);
							}
						}
					}
					$db->sql_freeresult($result);
				}

				$sql = 'SELECT COUNT(newsletter_id) AS num_newsletters
					FROM ' . NEWSLETTER_TABLE;
				$result = $db->sql_query($sql);
				$newsletters_count = (int) $db->sql_fetchfield('num_newsletters');
				$db->sql_freeresult($result);

				if (!$newsletters_count)
				{
					trigger_error('NO_NEWSLETTERS');
				}

				// Make sure $start is set to the last page if it exceeds the amount
				if ($start < 0 || $start > $newsletters_count)
				{
					$start = ($start < 0) ? 0 : floor(($newsletters_count - 1) / $config['topics_per_page']) * $config['topics_per_page'];
				}

				// If the user is trying to reach late pages, start searching from the end
				$sql_limit = $config['topics_per_page'];
				if ($start > $newsletters_count / 2)
				{
					if ($start + $config['topics_per_page'] > $newsletters_count)
					{
						$sql_limit = min($config['topics_per_page'], max(1, $newsletters_count - $start));
					}

					$sql_sort_order = 'DESC';
					$sql_start = max(0, $newsletters_count - $sql_limit - $start);
				}
				else
				{
					$sql_sort_order = 'ASC';
					$sql_start = $start;
				}

				$sql = 'SELECT newsletter_id, newsletter_name, newsletter_type, newsletter_desc, newsletter_desc_bitfield, newsletter_desc_uid, newsletter_desc_options, newsletter_lang FROM ' . NEWSLETTER_TABLE;
				$newsletter_array = $db->sql_query_limit($sql, $sql_limit, $sql_start);

				$in_groups = '';
				$group_id_ary = $newsletter_lang = array();

				while ($newsletter_row = $db->sql_fetchrow($newsletter_array))
				{
					if ($newsletter_row['newsletter_type'] == NEWSLETTER_GROUP)
					{
						$sql = 'SELECT group_id FROM ' . NEWSLETTER_GROUPS_TABLE . '
							WHERE newsletter_id = ' . (int) $newsletter_row['newsletter_id'] . '
							ORDER BY group_id ASC';
						$group_array = $db->sql_query($sql);
						while ($group_row = $db->sql_fetchrow($group_array))
						{
							$in_groups .= '<a href="' . append_sid("{$phpbb_root_path}memberlist.$phpEx", "mode=group&amp;g=" . $group_row['group_id'], true, $user->session_id) . '">' . get_group_name($group_row['group_id']) . '</a> ';
							$group_id_ary[] .= $group_row['group_id'];
						}
						$db->sql_freeresult($group_array);
					}
					if ($newsletter_row['newsletter_lang'])
					{
						$sql = 'SELECT lang_local_name
							FROM ' . LANG_TABLE . "
							WHERE lang_iso = '" . $db->sql_escape($newsletter_row['newsletter_lang']) . "'";
						$result = $db->sql_query($sql);
						$row = $db->sql_fetchrow($result);
						$newsletter_lang = $row['lang_local_name'];
						$db->sql_freeresult($result);
					}
					else
					{
						$newsletter_lang = '';
					}

					$template->assign_block_vars('newsletterlist', array(
						'ID'				=> $newsletter_row['newsletter_id'],
						'NAME'				=> $newsletter_row['newsletter_name'],
						'LANG'				=> $newsletter_lang,
						'LANG_IN'			=> sprintf(($newsletter_row['newsletter_lang'] == $user->data['user_lang']) ? $user->lang['NEWSLETTER_LANG_IN'] : $user->lang['NEWSLETTER_LANG_OUT'], '<a href="' . append_sid("{$phpbb_root_path}ucp.$phpEx?i=prefs&amp;mode=personal") . '">', '</a>'),
						'DESCRIPTION'		=> generate_text_for_display($newsletter_row['newsletter_desc'], $newsletter_row['newsletter_desc_uid'], $newsletter_row['newsletter_desc_bitfield'], $newsletter_row['newsletter_desc_options']),
						'S_IS_USER'			=> newsletter_user_status($user->data['user_id'], $newsletter_row['newsletter_id'], $newsletter_row['newsletter_type'], $newsletter_row['newsletter_lang']),
						'S_IS_LEADER'		=> newsletter_leader_status($user->data['user_id'], $newsletter_row['newsletter_id']),
						'S_OPTIONAL'		=> ($newsletter_row['newsletter_type'] == NEWSLETTER_OPTIONAL) ? true : false,
						'S_GROUP'			=> ($newsletter_row['newsletter_type'] == NEWSLETTER_GROUP) ? true : false,
						'S_BOARD'			=> ($newsletter_row['newsletter_type'] == NEWSLETTER_BOARD) ? true : false,
						'GROUPS'			=> $in_groups,
						'U_ARCHIVE'			=> append_sid("{$phpbb_root_path}newsletter_archive.$phpEx?n=" . $newsletter_row['newsletter_id']),
					));
				}
				$db->sql_freeresult($newsletter_array);

				$template->assign_vars(array(
					'L_TITLE'			=> $user->lang['UCP_NEWSLETTER_NEWSLETTERS'],
					'L_EXPLAIN'			=> $user->lang['NEWSLETTER_MANAGE_EXPLAIN'],
					'PAGINATION'		=> generate_pagination(append_sid("{$phpbb_root_path}ucp.$phpEx", "i=newsletter&amp;mode=newsletters"), $newsletters_count, $config['topics_per_page'], $start),
					'PAGE_NUMBER'		=> on_page($newsletters_count, $config['topics_per_page'], $start),
					'TOTAL_NEWSLETTERS'	=> ($newsletters_count == 1) ? $user->lang['VIEW_NEWSLETTER'] : sprintf($user->lang['VIEW_NEWSLETTERS'], $newsletters_count),
					'S_HIDDEN_FIELDS'	=> $s_hidden_fields,
					'S_UCP_ACTION'		=> $this->u_action,
					'MOD_VERSION'		=> $config['mnewsletter_version'],
					'S_UCP_BUTTONS'		=> newsletter_ucp_buttons()
				));

				$this->tpl_name = 'ucp_newsletter_' . $mode;
				$this->page_title = 'UCP_NEWSLETTER_' . strtoupper($mode);

				break;

			case 'preferences':

				if ($submit)
				{
					$setemailpref = request_var('setemailpref', $user->data['user_email_html']);
					$sql = 'UPDATE ' . USERS_TABLE . '
						SET user_email_html = ' . $db->sql_escape($setemailpref) . '
						WHERE user_id = ' . (int) $user->data['user_id'];
					$result = $db->sql_query($sql);
					$db->sql_freeresult($result);
					$user->data['user_email_html'] = $setemailpref;
				}

				$template->assign_vars(array(
					'S_HTML'			=> ($user->data['user_email_html'] == 1) ? true : false,
					'S_PLAIN'			=> ($user->data['user_email_html'] == 0) ? true : false,
					'USER_EMAIL'		=> sprintf($user->lang['NEWSLETTER_EMAIL_TOPICAL'], $user->data['user_email']),
					'U_CHANGE_EMAIL'	=> append_sid("{$phpbb_root_path}ucp.$phpEx?i=profile&amp;mode=reg_details"),
					'L_TITLE'			=> $user->lang['UCP_NEWSLETTER_PREFERENCES'],
					'L_EXPLAIN'			=> $user->lang['NEWSLETTER_PREF_EXPLAIN'],
					'S_HIDDEN_FIELDS'	=> $s_hidden_fields,
					'S_UCP_ACTION'		=> $this->u_action,
					'S_CHANGE_EMAIL'	=> ($auth->acl_get('u_chgemail')) ? true : false,
					'MOD_FOOTER'		=> sprintf($user->lang['NEWSLETTER_MOD'], strval($config['mnewsletter_version']))
				));

				$this->tpl_name = 'ucp_newsletter_' . $mode;
				$this->page_title = 'UCP_NEWSLETTER_' . strtoupper($mode);

				break;

		}

	}
};
?>
